@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -109,7 +109,6 @@ define([
          * {@link JXG.Point#makeGlider} and DO NOT set this property directly
          * as it will break the dependency tree.
          * @type JXG.GeometryElement
-         * @name Glider#slideObject
          */
         this.slideObject = null;
 
@@ -447,7 +446,7 @@ define([
                         newPos = c[1];
                     } else {
                         // side-effect: this.position is overwritten
-                        //this.coords.setCoordinates(Const.COORDS_BY_USER, Geometry.projectPointToCurve(this, slide, this.board).usrCoords, false);
+                        // this.coords.setCoordinates(Const.COORDS_BY_USER, Geometry.projectPointToCurve(this, slide, this.board).usrCoords, false);
                         newCoords = Geometry.projectPointToCurve(this, slide, this.board);
                         newPos = this.position; // save position for the overwriting below
                     }
@@ -557,7 +556,7 @@ define([
                     }
 
                     delta = beta - alpha;
-                    if (ev_ig) {
+                    if (Type.evaluate(this.visProp.isgeonext)) {
                         delta = 1.0;
                     }
                     angle = this.position * delta;
@@ -609,7 +608,8 @@ define([
                 //Homogeneous coords: ideal point
                 this.isReal = (Math.abs(this.coords.usrCoords[0]) > Mat.eps) ? this.isReal : false;
 
-                if (/*wasReal &&*/ !this.isReal) {
+                if (// wasReal &&
+                    !this.isReal) {
                     this.updateVisibility(false);
                 }
             }
@@ -1526,7 +1526,8 @@ define([
                     return i / steps;
                 };
 
-            if (!Type.exists(time) || time === 0 || (Math.abs(where.usrCoords[0] - this.coords.usrCoords[0]) > Mat.eps)) {
+            if (!Type.exists(time) || time === 0 ||
+                (Math.abs(where.usrCoords[0] - this.coords.usrCoords[0]) > Mat.eps)) {
                 this.setPosition(Const.COORDS_BY_USER, where.usrCoords);
                 return this.board.update(this);
             }
@@ -1754,12 +1755,9 @@ define([
                     el.baseElement = el;
                 }
                 el.isDraggable = true;
-            } else if (Type.isObject(coords[0]) &&
-                (Type.isObject(coords[1]) || // Transformation
-                 (Type.isArray(coords[1]) && coords[1].length > 0 && Type.isObject(coords[1][0]))
-                )) { // Array of transformations
-
+            } else if (Type.isObject(coords[0]) && Type.isTransformationOrArray(coords[1])) {
                 // Transformation
+                // TODO less general specification of isObject
                 el = new Callback(board, [0, 0], attr, arg1, arg2);
                 el.addTransform(coords[0], coords[1]);
                 el.isDraggable = false;
