@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -702,7 +702,7 @@ define([
         },
 
         /**
-         * Moves an by the difference of two coordinates.
+         * Moves an element by the difference of two coordinates.
          * @param {Number} method The type of coordinates used here.
          * Possible values are {@link JXG.COORDS_BY_USER} and {@link JXG.COORDS_BY_SCREEN}.
          * @param {Array} coords coordinates in screen/user units
@@ -906,7 +906,8 @@ define([
         hideElement: function () {
             JXG.deprecated('Element.hideElement()', 'Element.setDisplayRendNode()');
 
-            this.visPropCalc.visible = false;
+            // TODO: Does override value of  this.visProp.visible
+            this.visPropCalc.visible = this.visProp.visible = false;
             this.board.renderer.display(this, false);
 
             if (Type.exists(this.label) && this.hasLabel) {
@@ -927,7 +928,7 @@ define([
         showElement: function () {
             JXG.deprecated('Element.showElement()', 'Element.setDisplayRendNode()');
 
-            this.visPropCalc.visible = true;
+            this.visPropCalc.visible = this.visProp.visible = true;
             this.board.renderer.display(this, true);
 
             if (Type.exists(this.label) && this.hasLabel && this.label.hiddenByParent) {
@@ -1060,7 +1061,7 @@ define([
         },
 
         /**
-         * Sets a label and it's text
+         * Sets a label and its text
          * If label doesn't exist, it creates one
          * @param {String} str
          */
@@ -1260,7 +1261,8 @@ define([
                             if (!this.label) {
                                 this.createLabel();
                             }
-                            this.label.setDisplayRendNode(Type.evaluate(this.visProp.visible));
+                            this.label.showElement();
+                            //this.label.setDisplayRendNode(Type.evaluate(this.visProp.visible));
                         }
                         this.hasLabel = value;
                         break;
@@ -1297,6 +1299,12 @@ define([
                             this.rendNodeTag.disabled = !!value;
                         }
                         break;
+                    case 'checked':
+                        // checkbox Is not available on initial call.
+                        if (Type.exists(this.rendNodeTag)) {
+                            this.rendNodeCheckbox.checked = !!value;
+                        }
+                            break;
                     case 'maxlength':
                         // input. Is not available on initial call.
                         if (Type.exists(this.rendNodeTag)) {
@@ -1518,8 +1526,7 @@ define([
             //    through dehighlightAll.
 
             // highlight only if not highlighted
-            if (Type.evaluate(this.visProp.highlight)
-                    && (!this.highlighted || force)) {
+            if (Type.evaluate(this.visProp.highlight) && (!this.highlighted || force)) {
                 this.highlighted = true;
                 this.board.highlightedObjects[this.id] = this;
                 this.board.renderer.highlight(this);
