@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -67,7 +67,7 @@ define([
     JXG.Polygon = function (board, vertices, attributes) {
         this.constructor(board, attributes, Const.OBJECT_TYPE_POLYGON, Const.OBJECT_CLASS_AREA);
 
-        var i, vertex, l, len, j,
+        var i, l, len, j,
             attr_line = Type.copyAttributes(attributes, board.options, 'polygon', 'borders');
 
         this.withLines = attributes.withlines;
@@ -79,8 +79,7 @@ define([
          */
         this.vertices = [];
         for (i = 0; i < vertices.length; i++) {
-            vertex = this.board.select(vertices[i]);
-            this.vertices[i] = vertex;
+            this.vertices[i] = this.board.select(vertices[i]);
         }
 
         // Close the polygon
@@ -101,7 +100,8 @@ define([
                 i = (j + 1) % len;
                 attr_line.id = attr_line.ids && attr_line.ids[i];
                 attr_line.name = attr_line.names && attr_line.names[i];
-                attr_line.strokecolor = (Type.isArray(attr_line.colors) && attr_line.colors[i % attr_line.colors.length]) || attr_line.strokecolor;
+                attr_line.strokecolor = (Type.isArray(attr_line.colors) && attr_line.colors[i % attr_line.colors.length]) ||
+                                            attr_line.strokecolor;
                 attr_line.visible = Type.exists(attributes.borders.visible) ? attributes.borders.visible : attributes.visible;
 
                 if (attr_line.strokecolor === false) {
@@ -114,6 +114,7 @@ define([
                 l.parentPolygon = this;
             }
         }
+        this.inherits.push(this.vertices, this.borders);
 
         // Register polygon at board
         // This needs to be done BEFORE the points get this polygon added in their descendants list
@@ -121,8 +122,7 @@ define([
 
         // Add polygon as child to defining points
         for (i = 0; i < this.vertices.length - 1; i++) {
-            vertex = this.board.select(this.vertices[i]);
-            vertex.addChild(this);
+            this.board.select(this.vertices[i]).addChild(this);
         }
 
         this.board.renderer.drawPolygon(this);
@@ -139,6 +139,9 @@ define([
             vertices: 'vertices',
             A: 'Area',
             Area: 'Area',
+            Perimeter: 'Perimeter',
+            L: 'Perimeter',
+            Length: 'Perimeter',
             boundingBox: 'boundingBox',
             bounds: 'bounds',
             addPoints: 'addPoints',
@@ -160,10 +163,11 @@ define([
 
             var i, j, len, c = false;
 
-            if (this.visProp.hasinnerpoints) {
+            if (Type.evaluate(this.visProp.hasinnerpoints)) {
                 // All points of the polygon trigger hasPoint: inner and boundary points
                 len = this.vertices.length;
-                // See http://www.ecse.rpi.edu/Homepages/wrf/Research/Short_Notes/pnpoly.html for a reference
+                // See http://www.ecse.rpi.edu/Homepages/wrf/Research/Short_Notes/pnpoly.html
+                // for a reference of Jordan method
                 for (i = 0, j = len - 2; i < len - 1; j = i++) {
                     if (((this.vertices[i].coords.scrCoords[2] > y) !== (this.vertices[j].coords.scrCoords[2] > y)) &&
                             (x < (this.vertices[j].coords.scrCoords[1] - this.vertices[i].coords.scrCoords[1]) * (y - this.vertices[i].coords.scrCoords[2]) /
@@ -171,14 +175,20 @@ define([
                         c = !c;
                     }
                 }
-            } else {
-                // Only boundary points trigger hasPoint
-                len = this.borders.length;
-                for (i = 0; i < len; i++) {
-                    if (this.borders[i].hasPoint(x, y)) {
-                        c = true;
-                        break;
-                    }
+                if (c) {
+                    return true;
+                }
+            }
+
+            // Only boundary points trigger hasPoint
+            // We additionally test the boundary also in case hasInnerPoints.
+            // Since even if the above test has failed, the strokewidth may be large and (x, y) may
+            // be inside of hasPoint() of a vertices.
+            len = this.borders.length;
+            for (i = 0; i < len; i++) {
+                if (this.borders[i].hasPoint(x, y)) {
+                    c = true;
+                    break;
                 }
             }
 
@@ -189,16 +199,55 @@ define([
          * Uses the boards renderer to update the polygon.
          */
         updateRenderer: function () {
-            if (this.needsUpdate && this.visProp.visible) {
-                this.board.renderer.updatePolygon(this);
-                this.needsUpdate = false;
+            var i, len; // wasReal,
+
+
+            if (!this.needsUpdate) {
+                return this;
             }
 
-            if (this.hasLabel && this.label.visProp.visible) {
+            if (this.visPropCalc.visible) {
+                // wasReal = this.isReal;
+
+                len = this.vertices.length;
+                this.isReal = true;
+                for (i = 0; i < len; ++i) {
+                    if (!this.vertices[i].isReal) {
+                        this.isReal = false;
+                        break;
+                    }
+                }
+
+                if (//wasReal &&
+                    !this.isReal) {
+                    this.updateVisibility(false);
+                }
+            }
+
+            if (this.visPropCalc.visible) {
+                this.board.renderer.updatePolygon(this);
+            }
+
+            /* Update the label if visible. */
+            if (this.hasLabel && this.visPropCalc.visible && this.label &&
+                this.label.visPropCalc.visible && this.isReal) {
+
                 this.label.update();
                 this.board.renderer.updateText(this.label);
             }
 
+            // Update rendNode display
+            this.setDisplayRendNode();
+            // if (this.visPropCalc.visible !== this.visPropOld.visible) {
+            //     this.board.renderer.display(this, this.visPropCalc.visible);
+            //     this.visPropOld.visible = this.visPropCalc.visible;
+            //
+            //     if (this.hasLabel) {
+            //         this.board.renderer.display(this.label, this.label.visPropCalc.visible);
+            //     }
+            // }
+
+            this.needsUpdate = false;
             return this;
         },
 
@@ -268,8 +317,10 @@ define([
         hideElement: function (borderless) {
             var i;
 
-            this.visProp.visible = false;
-            this.board.renderer.hide(this);
+            JXG.deprecated('Element.hideElement()', 'Element.setDisplayRendNode()');
+
+            this.visPropCalc.visible = false;
+            this.board.renderer.display(this, false);
 
             if (!borderless) {
                 for (i = 0; i < this.borders.length; i++) {
@@ -279,7 +330,7 @@ define([
 
             if (this.hasLabel && Type.exists(this.label)) {
                 this.label.hiddenByParent = true;
-                if (this.label.visProp.visible) {
+                if (this.label.visPropCalc.visible) {
                     this.label.hideElement();
                 }
             }
@@ -293,22 +344,24 @@ define([
         showElement: function (borderless) {
             var i;
 
-            this.visProp.visible = true;
-            this.board.renderer.show(this);
+            JXG.deprecated('Element.showElement()', 'Element.setDisplayRendNode()');
+
+            this.visPropCalc.visible = true;
+            this.board.renderer.display(this, true);
 
             if (!borderless) {
                 for (i = 0; i < this.borders.length; i++) {
-                    this.borders[i].showElement();
-                    this.borders[i].updateRenderer();
+                    this.borders[i].showElement().updateRenderer();
                 }
             }
 
             if (Type.exists(this.label) && this.hasLabel && this.label.hiddenByParent) {
                 this.label.hiddenByParent = false;
-                if (!this.label.visProp.visible) {
+                if (!this.label.visPropCalc.visible) {
                     this.label.showElement().updateRenderer();
                 }
             }
+            return this;
         },
 
         /**
@@ -319,6 +372,38 @@ define([
             return Math.abs(Geometry.signedPolygon(this.vertices, true));
         },
 
+        /**
+         * Perimeter of polygon.
+         * @returns {Number} Perimeter of polygon in user units.
+         *
+         * @example
+         * var p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [1.0, 3.0]];
+         *
+         * var pol = board.create('polygon', p, {hasInnerPoints: true});
+         * var t = board.create('text', [5, 5, function() { return pol.Perimeter(); }]);
+         * </pre><div class="jxgbox" id="b10b734d-89fc-4b9d-b4a7-e3f0c1c6bf77" style="width: 400px; height: 400px;"></div>
+         * <script type="text/javascript">
+         *  (function () {
+         *   var board = JXG.JSXGraph.initBoard('b10b734d-89fc-4b9d-b4a7-e3f0c1c6bf77', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
+         *       p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [1.0, 4.0]],
+         *       cc1 = board.create('polygon', p, {hasInnerPoints: true}),
+         *       t = board.create('text', [5, 5, function() { return cc1.Perimeter(); }]);
+         *  })();
+         * </script><pre>
+         *
+         */
+        Perimeter: function() {
+            var i,
+                len = this.vertices.length,
+                val = 0.0;
+
+            for (i = 1; i < len; ++i) {
+                val += this.vertices[i].Dist(this.vertices[i - 1]);
+            }
+
+            return val;
+        },
+
         /**
          * Bounding box of a polygon. The bounding box is an array of four numbers: the first two numbers
          * determine the upper left corner, the last two number determine the lower right corner of the bounding box.
@@ -448,7 +533,7 @@ define([
                 }
 
                 tmp.push(this.board.create('segment', [this.vertices[idx + npoints.length], this.vertices[idx + npoints.length + 1]], this.attr_line));
-                this.borders = tmp.concat(this.borders.slice(idx));
+                this.borders = tmp.concat(this.borders.slice(idx + 1));
             }
 
             this.board.update();
@@ -478,8 +563,9 @@ define([
 
             // collect all valid parameters as indices in nidx
             for (i = 0; i < arguments.length; i++) {
-                if (Type.isPoint(arguments[i])) {
-                    idx = this.findPoint(arguments[i]);
+                idx = arguments[i];
+                if (Type.isPoint(idx)) {
+                    idx = this.findPoint(idx);
                 }
 
                 if (Type.isNumber(idx) && idx > -1 && idx < this.vertices.length && Type.indexOf(nidx, idx) === -1) {
@@ -487,6 +573,11 @@ define([
                 }
             }
 
+            // remove the polygon from each removed point's children
+            for (i = 0; i < nidx.length; i++) {
+                this.vertices[nidx[i]].removeChild(this);
+            }
+
             // sort the elements to be eliminated
             nidx = nidx.sort();
             nvertices = this.vertices.slice();
@@ -558,7 +649,7 @@ define([
                 }
 
                 // if the first and/or the last vertex is removed, the closing border is created at the end.
-                if (partition[0][1] === 5 || partition[partition.length - 1][1] === 0) {
+                if (partition[0][1] === this.vertices.length - 1 || partition[partition.length - 1][1] === 0) {
                     this.borders.push(this.board.create('segment', [this.vertices[0], this.vertices[this.vertices.length - 2]], this.attr_line));
                 }
             }
@@ -592,11 +683,18 @@ define([
         },
 
         snapToGrid: function () {
-            var i;
+            var i, force;
+
+            if (Type.evaluate(this.visProp.snaptogrid)) {
+                force = true;
+            } else {
+                force = false;
+            }
 
             for (i = 0; i < this.vertices.length; i++) {
-                this.vertices[i].snapToGrid();
+                this.vertices[i].handleSnapToGrid(force, true);
             }
+
         },
 
         /**
@@ -718,7 +816,7 @@ define([
          *  // Static version:
          *  // the intersection polygon does not adapt to changes of pol1 or pol2.
          *  var pol3 = board.create('polygon', pol1.intersect(pol2), {fillColor: 'blue'});
-         * </pre><div class="jxgbox"id="d1fe5ea9-309f-494a-af07-ee3d033acb7c" style="width: 300px; height: 300px;"></div>
+         * </pre><div class="jxgbox" id="d1fe5ea9-309f-494a-af07-ee3d033acb7c" style="width: 300px; height: 300px;"></div>
          * <script type="text/javascript">
          *   (function() {
          *       var board = JXG.JSXGraph.initBoard('d1fe5ea9-309f-494a-af07-ee3d033acb7c', {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
@@ -762,7 +860,7 @@ define([
          *      }
          *  };
          *  board.update();
-         * </pre><div class="jxgbox"id="f870d516-ca1a-4140-8fe3-5d64fb42e5f2" style="width: 300px; height: 300px;"></div>
+         * </pre><div class="jxgbox" id="f870d516-ca1a-4140-8fe3-5d64fb42e5f2" style="width: 300px; height: 300px;"></div>
          * <script type="text/javascript">
          *   (function() {
          *       var board = JXG.JSXGraph.initBoard('f870d516-ca1a-4140-8fe3-5d64fb42e5f2', {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
@@ -819,6 +917,10 @@ define([
      * @throws {Exception} If the element cannot be constructed with the given parent objects an exception is thrown.
      * @param {Array} vertices The polygon's vertices. If the first and the last vertex don't match the first one will be
      * added to the array by the creator.
+     *
+     * Additionally, a polygon can be created by providing a polygon and a transformation (or an array of transformations).
+     * The result is a polygon which is the transformation of the supplied polygon.
+     *
      * @example
      * var p1 = board.create('point', [0.0, 2.0]);
      * var p2 = board.create('point', [2.0, 1.0]);
@@ -826,7 +928,7 @@ define([
      * var p4 = board.create('point', [1.0, 4.0]);
      *
      * var pol = board.create('polygon', [p1, p2, p3, p4]);
-     * </pre><div class="jxgbox"id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('682069e9-9e2c-4f63-9b73-e26f8a2b2bb1', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -839,14 +941,14 @@ define([
      * </script><pre>
      *
      * @example
-     * var p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [4.0, 6.0], [4.0, 6.0], [1.0, 3.0]];
+     * var p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [1.0, 3.0]];
      *
      * var pol = board.create('polygon', p, {hasInnerPoints: true});
-     * </pre><div class="jxgbox"id="9f9a5946-112a-4768-99ca-f30792bcdefb" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="9f9a5946-112a-4768-99ca-f30792bcdefb" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('9f9a5946-112a-4768-99ca-f30792bcdefb', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
-     *       p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [4.0, 6.0], [4.0, 6.0], [1.0, 4.0]],
+     *       p = [[0.0, 2.0], [2.0, 1.0], [4.0, 6.0], [1.0, 4.0]],
      *       cc1 = board.create('polygon', p, {hasInnerPoints: true});
      *  })();
      * </script><pre>
@@ -858,7 +960,7 @@ define([
      *       f4 = function() { return [1.0, 4.0]; },
      *       cc1 = board.create('polygon', [f1, f2, f3, f4]);
      *
-     * </pre><div class="jxgbox"id="ceb09915-b783-44db-adff-7877ae3534c8" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="ceb09915-b783-44db-adff-7877ae3534c8" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('ceb09915-b783-44db-adff-7877ae3534c8', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -871,12 +973,25 @@ define([
      * </script><pre>
      */
     JXG.createPolygon = function (board, parents, attributes) {
-        var el, i, points = [],
+        var el, i, le, obj,
+            points = [],
             attr, p;
 
-        points = Type.providePoints(board, parents, attributes, 'polygon', ['vertices']);
-        if (points === false) {
-            throw new Error("JSXGraph: Can't create polygon with parent types other than 'point' and 'coordinate arrays' or a function returning an array of coordinates");
+        obj = board.select(parents[0]);
+        if (Type.isObject(obj) && obj.type === Const.OBJECT_TYPE_POLYGON &&
+            Type.isTransformationOrArray(parents[1])) {
+
+            le = obj.vertices.length - 1;
+            attr = Type.copyAttributes(attributes, board.options, 'polygon', 'vertices');
+            for (i = 0; i < le; i++) {
+                points.push(board.create('point', [obj.vertices[i], parents[1]], attr));
+            }
+
+        } else {
+            points = Type.providePoints(board, parents, attributes, 'polygon', ['vertices']);
+            if (points === false) {
+                throw new Error("JSXGraph: Can't create polygon with parent types other than 'point' and 'coordinate arrays' or a function returning an array of coordinates. Alternatively, a polygon and a transformation can be supplied");
+            }
         }
 
         attr = Type.copyAttributes(attributes, board.options, 'polygon');
@@ -886,7 +1001,6 @@ define([
         return el;
     };
 
-
     /**
      * @class Constructs a regular polygon. It needs two points which define the base line and the number of vertices.
      * @pseudo
@@ -902,7 +1016,7 @@ define([
      * var p2 = board.create('point', [2.0, 1.0]);
      *
      * var pol = board.create('regularpolygon', [p1, p2, 5]);
-     * </pre><div class="jxgbox"id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="682069e9-9e2c-4f63-9b73-e26f8a2b2bb1" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      *  (function () {
      *   var board = JXG.JSXGraph.initBoard('682069e9-9e2c-4f63-9b73-e26f8a2b2bb1', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -917,7 +1031,7 @@ define([
      * var p3 = board.create('point', [2.0,0.0]);
      *
      * var pol = board.create('regularpolygon', [p1, p2, p3]);
-     * </pre><div class="jxgbox"id="096a78b3-bd50-4bac-b958-3be5e7df17ed" style="width: 400px; height: 400px;"></div>
+     * </pre><div class="jxgbox" id="096a78b3-bd50-4bac-b958-3be5e7df17ed" style="width: 400px; height: 400px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('096a78b3-bd50-4bac-b958-3be5e7df17ed', {boundingbox: [-1, 9, 9, -1], axis: false, showcopyright: false, shownavigation: false}),
@@ -927,6 +1041,28 @@ define([
      *       cc1 = board.create('regularpolygon', [p1, p2, p3]);
      * })();
      * </script><pre>
+     *
+     * @example
+     *         // Line of reflection
+     *         var li = board.create('line', [1,1,1], {strokeColor: '#aaaaaa'});
+     *         var reflect = board.create('transform', [li], {type: 'reflect'});
+     *         var pol1 = board.create('polygon', [[-3,-2], [-1,-4], [-2,-0.5]]);
+     *         var pol2 = board.create('polygon', [pol1, reflect]);
+     *
+     * </pre><div id="58fc3078-d8d1-11e7-93b3-901b0e1b8723" class="jxgbox" style="width: 300px; height: 300px;"></div>
+     * <script type="text/javascript">
+     *     (function() {
+     *         var board = JXG.JSXGraph.initBoard('58fc3078-d8d1-11e7-93b3-901b0e1b8723',
+     *             {boundingbox: [-8, 8, 8,-8], axis: true, showcopyright: false, shownavigation: false});
+     *             var li = board.create('line', [1,1,1], {strokeColor: '#aaaaaa'});
+     *             var reflect = board.create('transform', [li], {type: 'reflect'});
+     *             var pol1 = board.create('polygon', [[-3,-2], [-1,-4], [-2,-0.5]]);
+     *             var pol2 = board.create('polygon', [pol1, reflect]);
+     *
+     *     })();
+     *
+     * </script><pre>
+     *
      */
     JXG.createRegularPolygon = function (board, parents, attributes) {
         var el, i, n,
@@ -957,7 +1093,7 @@ define([
             rot = board.create('transform', [Math.PI * (2 - (n - 2) / n), p[i - 1]], {type: 'rotate'});
             if (pointsExist) {
                 p[i].addTransform(p[i - 2], rot);
-                p[i].prepareUpdate().update().updateRenderer();
+                p[i].fullUpdate();
             } else {
                 if (Type.isArray(attr.ids) && attr.ids.length >= n - 2) {
                     attr.id = attr.ids[i - 2];
@@ -972,7 +1108,7 @@ define([
             }
         }
 
-        attr = Type.copyAttributes(attributes, board.options, 'polygon');
+        attr = Type.copyAttributes(attributes, board.options, 'regularpolygon');
         el = board.create('polygon', p, attr);
         el.elType = 'regularpolygon';
 
