@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -95,6 +95,12 @@ define([
         // Only used by infobox anymore
         this.hiddenByParent = false;
 
+        /**
+         * Width and height of the the text element in pixel.
+         *
+         * @private
+         * @type {Array}
+         */
         this.size = [1.0, 1.0];
         this.id = this.board.setId(this, 'T');
 
@@ -144,7 +150,7 @@ define([
                 y = lft[2];
             }
 
-            ax = Type.evaluate(this.visProp.anchorx);
+            ax = this.getAnchorX();
             if (ax === 'right') {
                 lft = this.coords.scrCoords[1] - this.size[0];
             } else if (ax === 'middle') {
@@ -154,7 +160,7 @@ define([
             }
             rt = lft + this.size[0];
 
-            ay = Type.evaluate(this.visProp.anchory);
+            ay = this.getAnchorY();
             if (ay === 'top') {
                 bot = this.coords.scrCoords[2] + this.size[1];
             } else if (ay === 'middle') {
@@ -194,11 +200,11 @@ define([
                         this.plaintext = resolvedText;
                     }
                 };
-            } else if (Type.isString(text) && !ev_p) {
+            } else if (Type.isString(text) && !ev_p) {   // Do not parse
                 this.updateText = function () {
                     this.plaintext = text;
                 };
-            } else {
+            } else {                                     // Parse
                 if (Type.isNumber(text)) {
                     this.content = Type.toFixed(text, Type.evaluate(this.visProp.digits));
                 } else {
@@ -210,7 +216,8 @@ define([
                     } else {
                         // Converts GEONExT syntax into JavaScript string
                         // Short math is allowed
-                        this.content = this.generateTerm(text, true);
+                        // Avoid geonext2JS calls
+                        this.content = this.generateTerm(text, true, true);
                     }
                 }
                 updateText = this.board.jc.snippet(this.content, true, '', false);
@@ -278,13 +285,15 @@ define([
 
         /**
          * Recompute the width and the height of the text box.
-         * Update array this.size with pixel values.
+         * Updates the array {@link JXG.Text#size} with pixel values.
          * The result may differ from browser to browser
          * by some pixels.
          * In canvas an old IEs we use a very crude estimation of the dimensions of
          * the textbox.
-         * In JSXGraph this.size is necessary for applying rotations in IE and
+         * JSXGraph needs {@link JXG.Text#size} for applying rotations in IE and
          * for aligning text.
+         *
+         * @return {[type]} [description]
          */
         updateSize: function () {
             var tmp, s, that, node,
@@ -479,7 +488,9 @@ define([
             this.updateText();
 
             if (Type.evaluate(this.visProp.display) === 'internal') {
-                this.plaintext = this.utf8_decode(this.plaintext);
+                if (Type.isString(this.plaintext)) {
+                    this.plaintext = this.utf8_decode(this.plaintext);
+                }
             }
 
             this.checkForSizeUpdate();
@@ -544,10 +555,12 @@ define([
          *
          * @param{String} contentStr String to be parsed
          * @param{Boolean} [expand] Optional flag if shortened math syntax is allowed (e.g. 3x instead of 3*x).
+         * @param{Boolean} [avoidGeonext2JS] Optional flag if geonext2JS should be called. For backwards compatibility
+         * this has to be set explicitely to true.
          * @private
          * @see JXG.GeonextParser.geonext2JS.
          */
-        generateTerm: function (contentStr, expand) {
+        generateTerm: function (contentStr, expand, avoidGeonext2JS) {
             var res, term, i, j,
                 plaintext = '""';
 
@@ -577,7 +590,11 @@ define([
                     if (expand === true) {
                         term = this.expandShortMath(term);
                     }
-                    res = GeonextParser.geonext2JS(term, this.board);
+                    if (avoidGeonext2JS) {
+                        res = term;
+                    } else {
+                        res = GeonextParser.geonext2JS(term, this.board);
+                    }
                     res = res.replace(/\\"/g, "'");
                     res = res.replace(/\\'/g, "'");
 
@@ -683,6 +700,48 @@ define([
             } else {
                 return [c[1], c[2] + this.size[1] / this.board.unitY, c[1] + this.size[0] / this.board.unitX, c[2]];
             }
+        },
+
+        getAnchorX: function() {
+            var a = Type.evaluate(this.visProp.anchorx);
+            if (a == 'auto') {
+                switch (this.visProp.position) {
+                    case 'top':
+                    case 'bot':
+                        return 'middle';
+                    case 'rt':
+                    case 'lrt':
+                    case 'urt':
+                        return 'left';
+                    case 'lft':
+                    case 'llft':
+                    case 'ulft':
+                    default:
+                        return 'right';
+                }
+            }
+            return a;
+        },
+
+        getAnchorY: function() {
+            var a = Type.evaluate(this.visProp.anchory);
+            if (a == 'auto') {
+                switch (this.visProp.position) {
+                    case 'top':
+                    case 'ulft':
+                    case 'urt':
+                        return 'bottom';
+                    case 'bot':
+                    case 'lrt':
+                    case 'llft':
+                        return 'top';
+                    case 'rt':
+                    case 'lft':
+                    default:
+                        return 'middle';
+                }
+            }
+            return a;
         }
     });
 
@@ -818,10 +877,8 @@ define([
         t.type = Type.OBJECT_TYPE_HTMLSLIDER;
 
         t.rendNodeForm = t.rendNode.childNodes[0];
-        t.rendNodeForm.id = t.rendNode.id + '_form';
 
         t.rendNodeRange = t.rendNodeForm.childNodes[0];
-        t.rendNodeRange.id = t.rendNode.id + '_range';
         t.rendNodeRange.min = parents[1][0];
         t.rendNodeRange.max = parents[1][2];
         t.rendNodeRange.step = attr.step;
@@ -835,9 +892,16 @@ define([
         }
 
         t.rendNodeOut = t.rendNodeForm.childNodes[2];
-        t.rendNodeOut.id = t.rendNode.id + '_out';
         t.rendNodeOut.value = parents[1][1];
 
+        try {
+            t.rendNodeForm.id = t.rendNode.id + '_form';
+            t.rendNodeRange.id = t.rendNode.id + '_range';
+            t.rendNodeOut.id = t.rendNode.id + '_out';
+	} catch (e) {
+            JXG.debug(e);
+        }
+
         t.rendNodeRange.style.width = attr.widthrange + 'px';
         t.rendNodeRange.style.verticalAlign = 'middle';
         t.rendNodeOut.style.width = attr.widthout + 'px';
