@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -102,6 +102,8 @@ define([
          */
         this.equidistant = false;
 
+        this.labelsData = [];
+
         if (Type.isFunction(ticks)) {
             this.ticksFunction = ticks;
             throw new Error("Function arguments are no longer supported.");
@@ -447,11 +449,11 @@ define([
                         Type.evaluate(this.line.visProp.strokewidth));
             point1.setCoordinates(Const.COORDS_BY_SCREEN, [
                     point1.scrCoords[1] - obj.d1x,
-                    point1.scrCoords[2] - obj.d1y,
+                    point1.scrCoords[2] - obj.d1y
                 ]);
             point2.setCoordinates(Const.COORDS_BY_SCREEN, [
                     point2.scrCoords[1] - obj.d2x,
-                    point2.scrCoords[2] - obj.d2y,
+                    point2.scrCoords[2] - obj.d2y
                 ]);
 
             // Calculate distance from Zero to P1 and to P2
@@ -591,13 +593,14 @@ define([
         adjustTickDistance: function (ticksDelta, coordsZero, deltas) {
             var nx, ny, bounds,
                 distScr,
-                sgn = 1;
+                sgn = 1,
+                ev_minti = Type.evaluate(this.visProp.minorticks);
 
             bounds = this.getLowerAndUpperBounds(coordsZero, 'ticksdistance');
             nx = coordsZero.usrCoords[1] + deltas.x * ticksDelta;
             ny = coordsZero.usrCoords[2] + deltas.y * ticksDelta;
             distScr = coordsZero.distance(Const.COORDS_BY_SCREEN, new Coords(Const.COORDS_BY_USER, [nx, ny], this.board));
-            while (distScr / (Type.evaluate(this.visProp.minorticks) + 1) < this.minTicksDistance) {
+            while (distScr / (ev_minti + 1) < this.minTicksDistance) {
                 if (sgn === 1) {
                     ticksDelta *= 2;
                 } else {
@@ -881,7 +884,7 @@ define([
          * @returns {Object} with properties 'x', 'y', 't' (text), 'i' (tick number) or null in case of o label
          * @private
          */
-         generateLabelData: function (labelText, tick, tickNumber) {
+        generateLabelData: function (labelText, tick, tickNumber) {
              var xa, ya, m, fs;
 
              // Test if large portions of the label are inside of the canvas
@@ -1134,7 +1137,7 @@ define([
     };
 
     /**
-     * @class Hashes can be used to mark congruent lines.
+     * @class Hatches can be used to mark congruent lines.
      * @pseudo
      * @description
      * @name Hatch
