@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2016
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -72,7 +72,7 @@ define([
      * var p2 = board.create('point', [1,1]);
      * var p3 = board.create('point', [3,1]);
      * var tape = board.create('tapemeasure', [[1, 2], [4, 2]], {name:'dist'});
-     * </pre><div class="jxgbox"id="6d9a2cda-22fe-4cd1-9d94-34283b1bdc01" style="width: 200px; height: 200px;"></div>
+     * </pre><div class="jxgbox" id="6d9a2cda-22fe-4cd1-9d94-34283b1bdc01" style="width: 200px; height: 200px;"></div>
      * <script type="text/javascript">
      *   (function () {
      *     var board = JXG.JSXGraph.initBoard('6d9a2cda-22fe-4cd1-9d94-34283b1bdc01', {boundingbox: [-1, 5, 5, -1], axis: true, showcopyright: false, shownavigation: false});
@@ -113,6 +113,7 @@ define([
             attr.withlabel = true;
         }
         li = board.create('segment', [p1, p2], attr);
+        // p1, p2 are already added to li.inherits
 
         if (withText) {
             if (attributes.name && attributes.name !== '') {
@@ -121,7 +122,7 @@ define([
                 n = '';
             }
             li.label.setText(function () {
-                return n + p1.Dist(p2).toFixed(precision);
+                return n + Type.toFixed(p1.Dist(p2), precision);
             });
         }
 
@@ -129,6 +130,7 @@ define([
             attr = Type.copyAttributes(attributes, board.options, 'tapemeasure', 'ticks');
             //ticks  = 2;
             ti = board.create('ticks', [li, 0.1], attr);
+            li.inherits.push(ti);
         }
 
         // override the segments's remove method to ensure the removal of all elements
@@ -170,6 +172,14 @@ define([
             Value: 'Value'
         });
 
+        li.prepareUpdate().update();
+        if (!board.isSuspendedUpdate) {
+            li.updateVisibility().updateRenderer();
+            // The point updates are necessary in case of snapToGrid==true
+            li.point1.updateVisibility().updateRenderer();
+            li.point2.updateVisibility().updateRenderer();
+        }
+
         return li;
     };
 
