@@ -88,7 +88,7 @@ define([
      *
      *     st = board.create('slopetriangle', [t]);
      *
-     * </pre><div class="jxgbox"id="951ccb6a-52bc-4dc2-80e9-43db064f0f1b" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="951ccb6a-52bc-4dc2-80e9-43db064f0f1b" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('951ccb6a-52bc-4dc2-80e9-43db064f0f1b', {boundingbox: [-5, 5, 5, -5], axis: true, showcopyright: false, shownavigation: false}),
@@ -109,7 +109,7 @@ define([
      *
      *     st = board.create('slopetriangle', [li, p]);
      *
-     * </pre><div class="jxgbox"id="b52f451c-22cf-4677-852a-0bb9d764ee95" style="width: 300px; height: 300px;"></div>
+     * </pre><div class="jxgbox" id="b52f451c-22cf-4677-852a-0bb9d764ee95" style="width: 300px; height: 300px;"></div>
      * <script type="text/javascript">
      * (function () {
      *   var board = JXG.JSXGraph.initBoard('b52f451c-22cf-4677-852a-0bb9d764ee95', {boundingbox: [-5, 5, 5, -5], axis: true, showcopyright: false, shownavigation: false}),
@@ -159,12 +159,17 @@ define([
         }], attr);
 
         attr = Type.copyAttributes(attributes, board.options, 'slopetriangle');
+        attr.borders = Type.copyAttributes(attr.borders, board.options, 'slopetriangle', 'borders');
         el = board.create('polygon', [tglide, glider, toppoint], attr);
 
         el.Value = priv.Value;
         el.tangent = tangent;
         el._isPrivateTangent = isPrivateTangent;
 
+        //el.borders[0].setArrow(false, {type: 2, size: 10});
+        //el.borders[1].setArrow(false, {type: 2, size: 10});
+        el.borders[2].setArrow(false, false);
+
         attr = Type.copyAttributes(attributes, board.options, 'slopetriangle', 'label');
         label = board.create('text', [
             function () { return glider.X() + 0.1; },
@@ -172,8 +177,10 @@ define([
             function () { return ''; }
         ], attr);
 
-        label._setText(function () { return el.Value().toFixed(label.visProp.digits); });
-        label.prepareUpdate().update().updateRenderer();
+        label._setText(function () {
+            return Type.toFixed(el.Value(), Type.evaluate(label.visProp.digits));
+        });
+        label.fullUpdate();
 
         el.glider = glider;
         el.basepoint = basepoint;
@@ -181,6 +188,15 @@ define([
         el.toppoint = toppoint;
         el.label = label;
 
+        el.subs = {
+            glider: glider,
+            basePoint: basepoint,
+            baseLine: baseline,
+            topPoint: toppoint,
+            label: label
+        };
+        el.inherits.push(glider, basepoint, baseline, toppoint, label);
+
         el.methodMap = JXG.deepCopy(el.methodMap, {
             tangent: 'tangent',
             glider: 'glider',
