@@ -474,72 +474,78 @@ define(['math/math', 'utils/type'], function (Mat, Type) {
         this.showR(x.l, hgt + 1);
     };
 
-
-    /**
-     * Heap
-     */
-    Mat.Heap = function () {
-        this.pq = [];
-        this.N = 0;
-    };
-
-    /**
-     * public
-     */
-    Mat.Heap.prototype.empty = function () {
-        this.pq = [];
-        this.N = 0;
-    };
-
-    Mat.Heap.prototype.insert = function (v) {
-        this.pq[this.N] = v;
-        this.N++;
-        this.fixUp(this.N);
-    };
-
-    Mat.Heap.prototype.delmax = function () {
-        this.exchange(0, this.N - 1);
-        this.fixDown(0, this.N - 1);
-        this.N--;
-
-        return this.pq[this.N];
-    };
-
-    /**
-     * private
-     */
-    Mat.Heap.prototype.fixUp = function (k) {
-        var i = k - 1;
-
-        while (i > 0 && this.pq[Math.floor(i / 2)] < this.pq[i]) {
-            this.exchange(Math.floor(i / 2), i);
-            i = Math.floor(i / 2);
-        }
-    };
-
-    Mat.Heap.prototype.fixDown = function (k, N) {
-        var j, i = k;
-        while (2 * i < N) {
-            j = 2 * i;
-
-            if (j < N && this.pq[j] < this.pq[j + 1]) {
-                j++;
-            }
-
-            if (this.pq[i] >= this.pq[j]) {
-                break;
-            }
-
-            this.exchange(i, j);
-            i = j;
-        }
-    };
-
-    Mat.Heap.prototype.exchange = function (i, j) {
-        var t = this.pq[i];
-        this.pq[i] = this.pq[j];
-        this.pq[j] = t;
-    };
-
     return Mat.BST;
 });
+
+define(['math/math', 'utils/type'], function (Mat, Type) {
+
+    "use strict";
+
+        /**
+         * Heap
+         */
+        Mat.Heap = function () {
+            this.pq = [];
+            this.N = 0;
+        };
+
+        /**
+         * public
+         */
+        Mat.Heap.prototype.empty = function () {
+            this.pq = [];
+            this.N = 0;
+        };
+
+        Mat.Heap.prototype.insert = function (node) {
+            this.pq[this.N] = node;
+            this.N++;
+            this.fixUp(this.N);
+        };
+
+        Mat.Heap.prototype.delmax = function () {
+            this.exchange(0, this.N - 1);
+            this.fixDown(0, this.N - 1);
+            this.N--;
+
+            return this.pq[this.N];
+        };
+
+        /**
+         * private
+         */
+        Mat.Heap.prototype.fixUp = function (k) {
+            var i = k - 1;
+
+            while (i > 0 && this.pq[Math.floor(i / 2)].v < this.pq[i].v) {
+                this.exchange(Math.floor(i / 2), i);
+                i = Math.floor(i / 2);
+            }
+        };
+
+        Mat.Heap.prototype.fixDown = function (k, N) {
+            var j, i = k;
+            while (2 * i < N) {
+                j = 2 * i;
+
+                if (j < N && this.pq[j].v < this.pq[j + 1].v) {
+                    j++;
+                }
+
+                if (this.pq[i].v >= this.pq[j].v) {
+                    break;
+                }
+
+                this.exchange(i, j);
+                i = j;
+            }
+        };
+
+        Mat.Heap.prototype.exchange = function (i, j) {
+            var t = this.pq[i];
+            this.pq[i] = this.pq[j];
+            this.pq[j] = t;
+        };
+
+        return Mat.Heap;
+});
