@@ -10,20 +10,20 @@
     This file is part of JSXGraph.
 
     JSXGraph is free software dual licensed under the GNU LGPL or MIT License.
-    
+
     You can redistribute it and/or modify it under the terms of the
-    
+
       * GNU Lesser General Public License as published by
         the Free Software Foundation, either version 3 of the License, or
         (at your option) any later version
       OR
       * MIT License: https://github.com/jsxgraph/jsxgraph/blob/master/LICENSE.MIT
-    
+
     JSXGraph is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU Lesser General Public License for more details.
-    
+
     You should have received a copy of the GNU Lesser General Public License and
     the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
     and <http://opensource.org/licenses/MIT/>.
@@ -58,7 +58,7 @@ define([
          * @returns {String} Converted expression.
          */
         replacePow: function (te) {
-            var count, pos, c,
+            var count, pos, c, previousIndex,
                 leftop, rightop, pre, p, left, i, right, expr;
 
             // delete all whitespace immediately before and after all ^ operators
@@ -66,7 +66,14 @@ define([
 
             //  Loop over all ^ operators
             i = te.indexOf('^');
-            while (i >= 0) {
+            previousIndex = -1;
+
+            while (i >= 0 && i < te.length - 1) {
+                if (previousIndex === i) {
+                    throw new Error("JSXGraph: Error while parsing expression '" + te + "'");
+                }
+                previousIndex = i;
+
                 // left and right are the substrings before, resp. after the ^ character
                 left = te.slice(0, i);
                 right = te.slice(i + 1);
@@ -449,7 +456,7 @@ define([
                 if (elements.hasOwnProperty(el)) {
                     if (el !== me.name) {
                         if (elements[el].elementClass === Const.OBJECT_CLASS_TEXT) {
-                            if (!elements[el].visProp.islabel) {
+                            if (!Type.evaluate(elements[el].visProp.islabel)) {
                                 elmask = el.replace(/\[/g, '\\[');
                                 elmask = elmask.replace(/\]/g, '\\]');
 
