@@ -1,5 +1,5 @@
 /*
- Copyright 2008-2017
+ Copyright 2008-2018
  Matthias Ehmann,
  Michael Gerhaeuser,
  Carsten Miller,
@@ -132,6 +132,7 @@
         generateJCode: function (step, board, step_log) {
             var i, j, k, sub_id, str, str1, str2, objects, pid1, pid2, pid3,
                 xstart, ystart, el, arr, step2, options, assign, attrid,
+                le, x, y, points,
                 copy_log = [],
                 set_str = '',
                 reset_str = '',
@@ -249,25 +250,102 @@
                     break;
 
                 case JXG.GENTYPE_REFLECTION:
-                    set_str = assign + 'reflection(' + step.src_ids[0] + ', ' + step.src_ids[1] + ') <<' + attrid;
-                    set_str += 'fillColor: \'' + step.args.fillColor + '\'';
-                    if (JXG.exists(step.args.strokeColor)) {
-                        set_str += ', strokeColor: \'' + step.args.strokeColor + '\'';
-                        set_str += ', opacity: \'' + step.args.opacity + '\'';
+                    // Polygon:
+                    if (step.src_ids.length > 2) {
+                        set_str = '';
+                        el = step.src_ids[step.src_ids.length - 1];
+                        for (i = 1; i < step.src_ids.length - 1; i++) {
+                            set_str += assign + 'reflection(' + step.src_ids[i] + ', ' + el + ') <<id:"' + step.dest_sub_ids[i - 1] + '"';
+                            set_str += ', name: ""';
+                            set_str += ', snaptogrid: ' + JXG.Options.elements.snapToGrid;
+                            set_str += ', snaptopoints: ' + JXG.Options.elements.snapToPoints + '>>;\n';
+                        }
+
+                        le = step.dest_sub_ids.length / 2;
+                        set_str += assign + 'polygon(';
+                        set_str += step.dest_sub_ids.slice(0, le).join();
+                        set_str += ') <<borders: <<ids: [\'' + step.dest_sub_ids.slice(le, 2*le).join("\', \'") + '\']';
+                        x = [];
+                        for (i = 0; i < le; i++) {
+                            x.push("\'\'");
+                        }
+                        set_str += ', names: [' + x.join() + ']';
+                        set_str += '>>, ' + attrid + ' fillOpacity: ';
+                        set_str += step.args.opacity + ', name: \'\', hasInnerPoints:' + JXG.Options.polygon.hasInnerPoints;
+                        set_str += ', fillColor: \'' + step.args.fillColor + '\'';
+                        set_str += ', snaptogrid: ' + JXG.Options.elements.snapToGrid;
+                        set_str += ', snaptopoints: ' + JXG.Options.elements.snapToPoints + ', scalable:true>>; ';
+
+                        for (i = 0; i < step.dest_sub_ids.length; i++) {
+                            if (step.dest_sub_ids[i] !== 0) {
+                                reset_str = 'delete ' + step.dest_sub_ids[i] + '; ' + reset_str;
+                            }
+                        }
+
+                        reset_str = 'delete ' + step.dest_id + '; ' + reset_str;
+
+                    } else {
+                        set_str = assign + 'reflection(' + step.src_ids[0] + ', ' + step.src_ids[1] + ') <<' + attrid;
+                        set_str += 'fillColor: \'' + step.args.fillColor + '\'';
+                        if (JXG.exists(step.args.strokeColor)) {
+                            set_str += ', strokeColor: \'' + step.args.strokeColor + '\'';
+                            set_str += ', opacity: \'' + step.args.opacity + '\'';
+                        }
+                        set_str += ', name: "' + step.args.name + '"';
+                        set_str += ', id: "' + step.dest_id + '"';
+                        if (step.args.name !== '') {
+                            set_str += ', withLabel: true';
+                        }
+                        set_str += '>>; ';
+                        reset_str = 'delete ' + step.dest_id + '; ';
                     }
-                    set_str += ', name: "' + step.args.name + '">>; ';
-                    reset_str = 'delete ' + step.dest_id + '; ';
+
                     break;
 
-                case JXG.GENTYPE_MIRRORPOINT:
-                    set_str = assign + 'mirrorpoint(' + step.src_ids[1] + ', ' + step.src_ids[0] + ') <<' + attrid;
-                    set_str += 'fillColor: \'' + step.args.fillColor + '\'';
-                    if (JXG.exists(step.args.strokeColor)) {
-                        set_str += ', strokeColor: \'' + step.args.strokeColor + '\'';
-                        set_str += ', opacity: \'' + step.args.opacity + '\'';
+                case JXG.GENTYPE_MIRRORELEMENT:
+                    if (step.src_ids.length > 2) {
+                        set_str = '';
+                        el = step.src_ids[step.src_ids.length - 1];
+                        for (i = 1; i < step.src_ids.length - 1; i++) {
+                            set_str += assign + 'mirrorelement(' + step.src_ids[i] + ', ' + el + ') <<id:"' + step.dest_sub_ids[i - 1] + '"';
+                            set_str += ', name: ""';
+                            set_str += ', snaptogrid: ' + JXG.Options.elements.snapToGrid;
+                            set_str += ', snaptopoints: ' + JXG.Options.elements.snapToPoints + '>>;\n';
+                        }
+
+                        le = step.dest_sub_ids.length / 2;
+                        set_str += assign + 'polygon(';
+                        set_str += step.dest_sub_ids.slice(0, le).join();
+                        set_str += ') <<borders: <<ids: [\'' + step.dest_sub_ids.slice(le, 2*le).join("\', \'") + '\']';
+                        x = [];
+                        for (i = 0; i < le; i++) {
+                            x.push("\'\'");
+                        }
+                        set_str += ', names: [' + x.join() + ']';
+                        set_str += '>>, ' + attrid + ' fillOpacity: ';
+                        set_str += step.args.opacity + ', name: \'\', hasInnerPoints:' + JXG.Options.polygon.hasInnerPoints;
+                        set_str += ', fillColor: \'' + step.args.fillColor + '\'';
+                        set_str += ', snaptogrid: ' + JXG.Options.elements.snapToGrid;
+                        set_str += ', snaptopoints: ' + JXG.Options.elements.snapToPoints + ', scalable:true>>; ';
+
+                        for (i = 0; i < step.dest_sub_ids.length; i++) {
+                            if (step.dest_sub_ids[i] !== 0) {
+                                reset_str = 'delete ' + step.dest_sub_ids[i] + '; ' + reset_str;
+                            }
+                        }
+
+                        reset_str = 'delete ' + step.dest_id + '; ' + reset_str;
+
+                    } else {
+                        set_str = assign + 'mirrorelement(' + step.src_ids[0] + ', ' + step.src_ids[1] + ') <<' + attrid;
+                        set_str += 'fillColor: \'' + step.args.fillColor + '\'';
+                        if (JXG.exists(step.args.strokeColor)) {
+                            set_str += ', strokeColor: \'' + step.args.strokeColor + '\'';
+                            set_str += ', opacity: \'' + step.args.opacity + '\'';
+                        }
+                        set_str += ', name: "' + step.args.name + '">>; ';
+                        reset_str = 'delete ' + step.dest_id + '; ';
                     }
-                    set_str += ', name: "' + step.args.name + '">>; ';
-                    reset_str = 'delete ' + step.dest_id + '; ';
                     break;
 
                 case JXG.GENTYPE_TANGENT:
@@ -680,7 +758,7 @@
                         }
 
                         set_str = 'point(' + str1.join(', ') + ') <<id: \'' + pid1 + '\', name: \'\', visible: true, ';
-                        set_str += 'snaptogrid: false, snaptopoints: false, priv: false>>; ';
+                        set_str += 'snaptogrid: ' + JXG.Options.elements.snapToGrid + ', snaptopoints: false, priv: false>>; ';
                         reset_str = 'delete ' + pid1 + '; ';
                     } else {
                         pid1 = step.src_ids[j];
@@ -696,7 +774,7 @@
 
                         set_str += 'point(' + str1.join(', ') + ') <<id: \'' + pid2 + '\', name: \'\', visible: true, ';
                         set_str += 'layer: ' + JXG.Options.layer.line + ', opacity: 0.2, ';
-                        set_str += 'snaptogrid: false, snaptopoints: false, priv: false>>; ';
+                        set_str += 'snaptogrid: ' + JXG.Options.elements.snapToGrid + ', snaptopoints: false, priv: false>>; ';
                         reset_str = 'delete ' + pid2 + '; ' + reset_str;
                     } else {
                         pid2 = step.src_ids[j];
@@ -956,15 +1034,17 @@
                     // step.src_ids[0] may contain one or two parent elements.
                     set_str = assign + 'slopetriangle(' + step.src_ids.join(', ') + ') <<';
                     set_str += attrid + ' name: \'\',';
-                    set_str += 'borders: <<ids: [\'' + step.dest_sub_ids[4] + '\', \'' + step.dest_sub_ids[5] + '\', \'' + step.dest_sub_ids[6] + '\']>>,';
-                    set_str += 'basepoint: <<id: \'' + step.dest_sub_ids[0] + '\', priv: false >>, baseline: <<id: \'' + step.dest_sub_ids[1] + '\', priv: true >>,';
-                    set_str += 'glider: <<id: \'' + step.dest_sub_ids[2] + '\', priv: false >>, toppoint: <<id: \'' + step.dest_sub_ids[3] + '\', priv: false >>';
+                    set_str += 'borders:   <<ids: [\'' + step.dest_sub_ids[4] + '\', \'' + step.dest_sub_ids[5] + '\', \'' + step.dest_sub_ids[6] + '\']>>,';
+                    set_str += 'basepoint: <<id: \'' + step.dest_sub_ids[0] + '\', priv: true >>, ';
+                    set_str += 'baseline:  <<id: \'' + step.dest_sub_ids[1] + '\', priv: true >>,';
+                    set_str += 'glider:    <<id: \'' + step.dest_sub_ids[2] + '\', priv: false >>, ';
+                    set_str += 'toppoint:  <<id: \'' + step.dest_sub_ids[3] + '\', priv: false >>';
                     if (step.dest_sub_ids.length === 8) {  // The test is needed for backwards compatibility
-                        set_str += ', tangent: <<id: \'' + step.dest_sub_ids[2] +
+                        set_str += ', tangent: <<id: \'' + step.dest_sub_ids[7] +
                                     '\', priv: true, point1: <<priv: true >>, point2: <<priv: true >> >>';
                     }
                     set_str += '>>;';
-                    reset_str = 'delete ' + step.dest_id + '; ';
+                    reset_str = 'remove(' + step.dest_id + '); ';
 
                     break;
 
@@ -990,6 +1070,51 @@
 
                     break;
 
+                case JXG.GENTYPE_PATH:
+                        le = step.args.points.length;
+
+                        if (step.args.doSpline) {
+                            set_str = assign +  'cardinalspline([';
+                        } else {
+                            set_str = assign +  'curve(';
+                        }
+                        for (i = 0; i < le; i++) {
+                            if (JXG.isString(step.args.points[i])) {
+                                set_str += '\'' + step.args.points[i] + '\'';
+                            } else {
+                                x = step.args.points[i][0].toPrecision(4);
+                                y = step.args.points[i][1].toPrecision(4);
+                                set_str += '[' + x + ',' + y + ']';
+                            }
+                            if (i < le - 1) {
+                                set_str += ',';
+                            }
+                        }
+
+                        if (step.args.doSpline ) {
+                            set_str += '], ' + step.args.tau + ', ' + step.args.type;
+                        }
+                        set_str += ') <<';
+
+                        set_str += attrid + 'name: \'\', withLabel: false, ';
+                        set_str += 'fixed: false, ';
+                        if (step.args.doSpline) {
+                            set_str += 'createPoints: false, ';
+                        }
+                        set_str += 'isArrayOfCoordinates: true, ';
+                        set_str += 'strokeWidth: ' + step.args.strokeWidth + ', ';
+                        set_str += 'strokeColor: \'' + step.args.strokeColor+ '\' >>; ';
+                        reset_str = 'delete ' + step.dest_id + '; ';
+
+                        break;
+
+                case JXG.GENTYPE_DERIVATIVE:
+                        set_str = assign +  'derivative(' + step.src_ids + ')';
+                        set_str += ' <<';
+                        set_str += 'dash: 2';
+                        set_str += ' >>;';
+                        break;
+
                 case JXG.GENTYPE_SLIDER:
                     set_str = assign + 'slider([' + pn(step.args.x1) + ', ' + pn(step.args.y1) + '], [' + pn(step.args.x2);
                     set_str += ', ' + pn(step.args.y2) + '], [' + pn(step.args.start) + ', ' + pn(step.args.ini) + ', ';
