@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -170,7 +170,7 @@ define([
         }
 
         // already documented in JXG.AbstractRenderer
-        this.supportsForeignObject = document.implementation.hasFeature("www.http://w3.org/TR/SVG11/feature#Extensibility", "1.1");
+        this.supportsForeignObject = document.implementation.hasFeature("http://w3.org/TR/SVG11/feature#Extensibility", "1.1");
 
         if (this.supportsForeignObject) {
             this.foreignObjLayer = this.container.ownerDocument.createElementNS(this.svgNamespace, 'foreignObject');
@@ -407,8 +407,8 @@ define([
         // already documented in JXG.AbstractRenderer
         updateInternalText: function (el) {
             var content = el.plaintext, v,
-                ev_ax = Type.evaluate(el.visProp.anchorx),
-                ev_ay = Type.evaluate(el.visProp.anchory);
+                ev_ax = el.getAnchorX(),
+                ev_ay = el.getAnchorY();
 
             if (el.rendNode.getAttributeNS(null, "class") !== el.visProp.cssclass) {
                 el.rendNode.setAttributeNS(null, "class", Type.evaluate(el.visProp.cssclass));
@@ -1024,9 +1024,11 @@ define([
             }
 
             len = nodes.length;
-            for (i = 0; i < len; ++i) if (el[nodes[i]]) {
-                node = el[nodes[i]];
-                node.style.transition = transitionStr;
+            for (i = 0; i < len; ++i) {
+                if (el[nodes[i]]) {
+                    node = el[nodes[i]];
+                    node.style.transition = transitionStr;
+                }
             }
 
             el.visPropOld.transitionduration = duration;
@@ -1331,24 +1333,29 @@ define([
         /**
          * Convert the SVG construction into an HTML canvas image.
          * This works for all SVG supporting browsers.
-         * For IE it works from version 9.
-         * But HTML texts are ignored on IE. The drawing is done with a delay of
-         * 200 ms. Otherwise there are problems with IE.
+         * For IE it works from version 9, with the execption that HTML texts
+         * are ignored on IE. The drawing is done with a delay of
+         * 200 ms. Otherwise there would be problems with IE.
+         *
          *
          * @param {String} canvasId Id of an HTML canvas element
          * @param {Number} w Width in pixel of the dumped image, i.e. of the canvas tag.
          * @param {Number} h Height in pixel of the dumped image, i.e. of the canvas tag.
+         * @param {Boolean} ignoreTexts If true, the foreignObject tag is taken out from the SVG root.
+         * This is necessary for Safari. Default: false
          * @returns {Object}          the svg renderer object.
          *
          * @example
          * 	board.renderer.dumpToCanvas('canvas');
          */
-        dumpToCanvas: function(canvasId, w, h) {
+        dumpToCanvas: function(canvasId, w, h, ignoreTexts) {
             var svgRoot = this.svgRoot,
                 btoa = window.btoa || Base64.encode,
                 svg, tmpImg, cv, ctx,
                 wOrg, hOrg,
-                uriPayload;
+                // uriPayload,
+                // DOMURL, svgBlob, url,
+                virtualNode, doc;
 
             // Move all HTML tags (beside the SVG root) of the container
             // to the foreignObject element inside of the svgRoot node
@@ -1356,6 +1363,11 @@ define([
                 while (svgRoot.nextSibling) {
                     this.foreignObjLayer.appendChild(svgRoot.nextSibling);
                 }
+                if (ignoreTexts === true) {
+                    doc = this.container.ownerDocument;
+                    virtualNode = doc.createElement('div');
+                    virtualNode.appendChild(this.foreignObjLayer);
+                }
             }
 
             svgRoot.setAttribute("xmlns", "http://www.w3.org/2000/svg");
@@ -1364,6 +1376,11 @@ define([
 
             svg = new XMLSerializer().serializeToString(svgRoot);
 
+            if (false) {
+                // Debug: example svg image
+                svg = '<svg xmlns="http://www.w3.org/2000/svg" version="1.0" width="220" height="220"><rect width="66" height="30" x="21" y="32" stroke="#204a87" stroke-width="2" fill="none" /></svg>';
+            }
+
             // In IE we have to remove the namespace again.
             if ((svg.match(/xmlns=\"http:\/\/www.w3.org\/2000\/svg\"/g) || []).length > 1) {
                 svg = svg.replace(/xmlns=\"http:\/\/www.w3.org\/2000\/svg\"/g, '');
@@ -1388,13 +1405,6 @@ define([
 
             tmpImg = new Image();
             if (true) {
-                tmpImg.onload = function () {
-                    // IE needs a pause...
-                    setTimeout(function(){
-                        ctx.drawImage(tmpImg, 0, 0, w, h);
-                    }, 200);
-                };
-
                 tmpImg.src = 'data:image/svg+xml;base64,' + btoa(unescape(encodeURIComponent(svg)));
                 // uriPayload = encodeURIComponent(svg.replace(/\n+/g, '')) // remove newlines // encode URL-unsafe characters
                 //             .replace(/%20/g, ' ') // put spaces back in
@@ -1403,25 +1413,35 @@ define([
                 //             .replace(/%2F/g, '/') // ditto slashes
                 //             .replace(/%22/g, "'");
                 // tmpImg.src = 'data:image/svg+xml,' + uriPayload;
-            } else {
-                // Alternative version
-                var DOMURL = window.URL || window.webkitURL || window;
-                var svgBlob = new Blob([svg], {type: 'image/svg+xml'});
-                var url = DOMURL.createObjectURL(svgBlob);
-                tmpImg.src = url;
 
                 tmpImg.onload = function () {
                     // IE needs a pause...
                     setTimeout(function(){
                         ctx.drawImage(tmpImg, 0, 0, w, h);
                     }, 200);
-                    DOMURL.revokeObjectURL(url);
                 };
+            } else {
+                // // Alternative version
+                // DOMURL = window.URL || window.webkitURL || window;
+                // svgBlob = new Blob([svg], {type: 'image/svg+xml'});
+                // url = DOMURL.createObjectURL(svgBlob);
+                // tmpImg.src = url;
+                //
+                // tmpImg.onload = function () {
+                //     // IE needs a pause...
+                //     setTimeout(function(){
+                //         ctx.drawImage(tmpImg, 0, 0, w, h);
+                //     }, 200);
+                //     DOMURL.revokeObjectURL(url);
+                // };
             }
 
             // Move all HTML tags back from
             // the foreignObject element to the container
             if (Type.exists(this.foreignObjLayer) && this.foreignObjLayer.hasChildNodes()) {
+                if (ignoreTexts === true) {
+                    svgRoot.appendChild(this.foreignObjLayer);
+                }
                 while (this.foreignObjLayer.firstChild) {
                     this.container.appendChild(this.foreignObjLayer.firstChild);
                 }
@@ -1430,85 +1450,136 @@ define([
             return this;
         },
 
-        screenshot: function(board) {
-            var node, doc, cPos,
+        /**
+         * Display SVG image in html img-tag which enables
+         * easy download for the user.
+         *
+         * Support:
+         * <ul>
+         * <li> IE: No
+         * <li> Edge: full
+         * <li>Firefox: full
+         * <li> Chrome: full
+         * <li> Safari: supported, but no texts (to be precise, no foreignObject-element is allowed in SVG)
+         * </ul>
+         *
+         * @param {JXG.Board} board Link to the board.
+         * @param {String} imgId Optional id of an img object. If given and different from the empty string,
+         * the screenshot is copied to this img object. The width and height will be set to the values of the
+         * JSXGraph container.
+         * @param {Boolean} ignoreTexts If set to true, the foreignObject is taken out of the
+         *  SVGRoot and texts are not displayed. This is mandatory for Safari. Default: false
+         * @return {Object}       the svg renderer object
+         */
+        screenshot: function(board, imgId, ignoreTexts) {
+            var node,
+                doc = this.container.ownerDocument,
+                parent = this.container.parentNode,
+                cPos,
                 canvas, id,
                 img,
                 button, buttonText,
                 w, h,
                 bas = board.attr.screenshot,
-                zbar, zbarDisplay,
-                cssTxt;
+                zbar, zbarDisplay, cssTxt,
+                newImg = false,
+                isDebug = false;
 
             if (this.type === 'no') {
-                return;
+                return this;
             }
 
-            w = bas.scale * parseFloat(board.containerObj.style.width);
-            h = bas.scale * parseFloat(board.containerObj.style.height);
+            w = bas.scale * parseFloat(this.container.style.width);
+            h = bas.scale * parseFloat(this.container.style.height);
+
+            if (imgId === undefined || imgId === '') {
+                newImg = true;
+                img = new Image(); //doc.createElement('img');
+                img.style.width = w + 'px';
+                img.style.height = h + 'px';
+            } else {
+                newImg = false;
+                img = doc.getElementById(imgId);
+            }
+            // img.crossOrigin = 'anonymous';
 
             // Create div which contains canvas element and close button
-            doc = board.containerObj.ownerDocument;
-            node = doc.createElement('div');
-            node.style.cssText = bas.css;
-            node.style.width = (w) + 'px';
-            node.style.height = (h) + 'px';
-            node.style.zIndex = board.containerObj.style.zIndex + 120;
+            if (newImg) {
+                node = doc.createElement('div');
+                node.style.cssText = bas.css;
+                node.style.width = (w) + 'px';
+                node.style.height = (h) + 'px';
+                node.style.zIndex = this.container.style.zIndex + 120;
 
-            // Position the div exactly over the JSXGraph board
-            cPos = board.getCoordsTopLeftCorner();
-            node.style.position= 'absolute';
-            node.style.left = (500+ cPos[0]) + 'px';
-            node.style.top = (cPos[1]) + 'px';
+                // Position the div exactly over the JSXGraph board
+                cPos = board.getCoordsTopLeftCorner();
+                node.style.position= 'absolute';
+                node.style.left = (cPos[0]) + 'px';
+                node.style.top = (cPos[1]) + 'px';
+            }
 
-            // Create canvas element
-            canvas = doc.createElement('canvas');
-            id = Math.random().toString(36).substr(2, 5);
-            canvas.setAttribute('id', id);
-            canvas.setAttribute('width', w);
-            canvas.setAttribute('height', h);
-            canvas.style.width = w + 'px';
-            canvas.style.height = w + 'px';
-            canvas.style.display = 'none';
+            if (!isDebug) {
+                // Create canvas element and add it to the DOM
+                // It will be removed after the image has been stored.
+                canvas = doc.createElement('canvas');
+                id = Math.random().toString(36).substr(2, 5);
+                canvas.setAttribute('id', id);
+                canvas.setAttribute('width', w);
+                canvas.setAttribute('height', h);
+                canvas.style.width = w + 'px';
+                canvas.style.height = w + 'px';
+                canvas.style.display = 'none';
+                parent.append(canvas);
+            } else {
+                // Debug: use canvas element
+                // 'jxgbox_canvas' from jsxdev/dump.html
+                id = 'jxgbox_canvas';
+                canvas = document.getElementById(id);
+            }
 
-            img = new Image(); //doc.createElement('img');
-            img.style.width = w + 'px';
-            img.style.height = h + 'px';
-            //img.crossOrigin = 'anonymous';
+            if (newImg) {
+                // Create close button
+                button = doc.createElement('span');
+                buttonText = doc.createTextNode('\u2716');
+                button.style.cssText = bas.cssButton;
+                button.appendChild(buttonText);
+                button.onclick = function() {
+                    node.parentNode.removeChild(node);
+                };
 
-            // Create close button
-            button = doc.createElement('span');
-            buttonText = doc.createTextNode('\u2716');
-            button.style.cssText = bas.cssButton;
-            button.appendChild(buttonText);
-            button.onclick = function() {
-                node.parentNode.removeChild(node);
-            };
-
-            // Add all nodes
-            node.appendChild(canvas);
-            node.appendChild(img);
-            node.appendChild(button);
-            board.containerObj.parentNode.appendChild(node);
+                // Add all nodes
+                node.appendChild(img);
+                node.appendChild(button);
+                parent.appendChild(node);
+            }
 
             // Hide navigation bar in board
-            zbar = document.getElementById(board.containerObj.id + '_navigationbar');
+            zbar = document.getElementById(this.container.id + '_navigationbar');
             if (Type.exists(zbar)) {
                 zbarDisplay = zbar.style.display;
                 zbar.style.display = 'none';
             }
 
             // Create screenshot in canvas
-            this.dumpToCanvas(id, w, h);
+            this.dumpToCanvas(id, w, h, ignoreTexts);
+
             // Show image in img tag
             setTimeout(function() {
+                //console.log(canvas.toDataURL('image/png'));
                 img.src = canvas.toDataURL('image/png');
+
+                // Remove canvas node
+                if (!isDebug) {
+                    parent.removeChild(canvas);
+                }
             }, 400);
 
             // Show navigation bar in board
             if (Type.exists(zbar)) {
                 zbar.style.display = zbarDisplay;
             }
+
+            return this;
         }
 
     });
