@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -126,7 +126,9 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
          * @returns {Boolean}
          */
         supportsPointerEvents: function () {
-            return this.isBrowser && window.navigator && (window.navigator.msPointerEnabled || window.navigator.pointerEnabled);
+            return !!(this.isBrowser && window.navigator &&
+                     // Chrome/IE11+                IE11+                              IE10-
+                    (/*window.PointerEvent ||*/ window.navigator.pointerEnabled || window.navigator.msPointerEnabled));
         },
 
         /**
@@ -204,7 +206,7 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
          * @type Number
          */
         ieVersion: (function () {
-            var undef, div, all,
+            var div, all,
                 v = 3;
 
             if (typeof document !== 'object') {
@@ -218,7 +220,7 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
                 div.innerHTML = '<!--[if gt IE ' + (++v) + ']><' + 'i><' + '/i><![endif]-->';
             } while (all[0]);
 
-            return v > 4 ? v : undef;
+            return v > 4 ? v : undefined;
 
         }()),
 
@@ -607,7 +609,7 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
          */
         getCSSTransformMatrix: function (obj) {
             var i, j, str, arrstr, start, len, len2, arr,
-                st, tr,
+                st,
                 doc = obj.ownerDocument,
                 t = ['transform', 'webkitTransform', 'MozTransform', 'msTransform', 'oTransform'],
                 mat = [[1, 0, 0],
