@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2017
+    Copyright 2008-2018
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -170,6 +170,23 @@ define([
             return this.isPoint(v);
         },
 
+        /**
+         * Checks if a given variable is a reference of a JSXGraph transformation element or an array
+         * of JSXGraph transformation elements.
+         * @param v A variable of any type.
+         * @returns {Boolean} True, if v is of type JXG.Transformation.
+         */
+        isTransformationOrArray: function(v) {
+            if (v !== null) {
+                if (this.isArray(v) && v.length > 0) {
+                    return this.isTransformationOrArray(v[0]);
+                } else if (typeof v === 'object') {
+                    return (v.type === Const.OBJECT_TYPE_TRANSFORMATION);
+                }
+            }
+            return false;
+        },
+
         /**
          * Checks if a given variable is neither undefined nor null. You should not use this together with global
          * variables!
@@ -596,7 +613,7 @@ define([
     	 */
     	_decimalAdjust: function(type, value, exp) {
     		// If the exp is undefined or zero...
-    		if (typeof exp === 'undefined' || +exp === 0) {
+    		if (exp === undefined || +exp === 0) {
     			return Math[type](value);
     		}
 
@@ -839,31 +856,35 @@ define([
             } else {
                 c = {};
                 for (i in obj) {
-                    i2 = toLower ? i.toLowerCase() : i;
-                    prop = obj[i];
-                    if (prop !== null && typeof prop === 'object') {
-                        if (this.exists(prop.board)) {
-                            c[i2] = prop.id;
+                    if (obj.hasOwnProperty(i)) {
+                        i2 = toLower ? i.toLowerCase() : i;
+                        prop = obj[i];
+                        if (prop !== null && typeof prop === 'object') {
+                            if (this.exists(prop.board)) {
+                                c[i2] = prop.id;
+                            } else {
+                                c[i2] = this.deepCopy(prop);
+                            }
                         } else {
-                            c[i2] = this.deepCopy(prop);
+                            c[i2] = prop;
                         }
-                    } else {
-                        c[i2] = prop;
                     }
                 }
 
                 for (i in obj2) {
-                    i2 = toLower ? i.toLowerCase() : i;
+                    if (obj2.hasOwnProperty(i)) {
+                        i2 = toLower ? i.toLowerCase() : i;
 
-                    prop = obj2[i];
-                    if (typeof prop === 'object') {
-                        if (this.isArray(prop) || !this.exists(c[i2])) {
-                            c[i2] = this.deepCopy(prop);
+                        prop = obj2[i];
+                        if (typeof prop === 'object') {
+                            if (this.isArray(prop) || !this.exists(c[i2])) {
+                                c[i2] = this.deepCopy(prop);
+                            } else {
+                                c[i2] = this.deepCopy(c[i2], prop, toLower);
+                            }
                         } else {
-                            c[i2] = this.deepCopy(c[i2], prop, toLower);
+                            c[i2] = prop;
                         }
-                    } else {
-                        c[i2] = prop;
                     }
                 }
             }
@@ -970,8 +991,10 @@ define([
             var key;
 
             subObject.prototype[constructorName] = superObject.prototype.constructor;
-            for (key in superObject.prototype)  {
-                subObject.prototype[key] = superObject.prototype[key];
+            for (key in superObject.prototype) {
+                if (superObject.prototype.hasOwnProperty(key)) {
+                    subObject.prototype[key] = superObject.prototype[key];
+                }
             }
         },
 
@@ -1062,7 +1085,7 @@ define([
                 strokewidth: '',
                 transitionduration: 0,
                 top: -100000,
-                visible: null,
+                visible: null
             };
 
             return el;
@@ -1203,10 +1226,11 @@ define([
          * @returns {String}
          */
         trim: function (str) {
-            str = str.replace(/^\s+/, '');
-            str = str.replace(/\s+$/, '');
-
-            return str;
+            // str = str.replace(/^\s+/, '');
+            // str = str.replace(/\s+$/, '');
+            //
+            // return str;
+            return str.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, '');
         },
 
         /**
